@@ -1,18 +1,5 @@
 # CLASSES DEFINITION
 
-# Vector =======================================================================
-.BootstrapVector <- setClass(
-  Class = "BootstrapVector",
-  contains = "numeric"
-)
-.JackknifeVector <- setClass(
-  Class = "JackknifeVector",
-  slots = c(
-    hat = "numeric"
-  ),
-  contains = "numeric"
-)
-
 # MultivariateAnalysis =========================================================
 ## Results ---------------------------------------------------------------------
 #' Multivariate Data Analysis Results
@@ -36,6 +23,7 @@
 #' @docType class
 #' @name MultivariateResults
 #' @aliases MultivariateResults-class
+#' @keywords internal
 .MultivariateResults <- setClass(
   Class = "MultivariateResults",
   slots = c(
@@ -72,6 +60,7 @@
 #' @docType class
 #' @name MultivariateAnalysis
 #' @aliases MultivariateAnalysis-class
+#' @keywords internal
 .MultivariateAnalysis <- setClass(
   Class = "MultivariateAnalysis",
   slots = c(
@@ -95,6 +84,7 @@
 #' @docType class
 #' @name MultivariateBootstrap
 #' @aliases MultivariateBootstrap-class
+#' @keywords internal
 .MultivariateBootstrap <- setClass(
   Class = "MultivariateBootstrap",
   slots = c(
@@ -117,6 +107,7 @@
 #' @docType class
 #' @name MultivariateSummary
 #' @aliases MultivariateSummary-class
+#' @keywords internal
 .MultivariateSummary <- setClass(
   Class = "MultivariateSummary",
   slots = c(
@@ -153,6 +144,7 @@
 #' @docType class
 #' @exportClass CA
 #' @aliases CA-class
+#' @keywords internal
 .CA <- setClass(
   Class = "CA",
   contains = "MultivariateAnalysis"
@@ -179,6 +171,7 @@
 #' @docType class
 #' @exportClass PCA
 #' @aliases PCA-class
+#' @keywords internal
 .PCA <- setClass(
   Class = "PCA",
   slots = c(
